==============================================
Essential Classes in sympy.vector (docstrings)
==============================================

CoordSys3D
=================

.. autoclass:: sympy.vector.coordsysrect.CoordSys3D
   :members:

   .. automethod:: sympy.vector.coordsysrect.CoordSys3D.__init__


Vector
======

.. autoclass:: sympy.vector.vector.Vector
   :members:


Dyadic
======

.. autoclass:: sympy.vector.dyadic.Dyadic
   :members:


Del
===

.. autoclass:: sympy.vector.deloperator.Del
   :members:
